"""
.. module:: annotpipe
    :platform: Unix, Windows, MacOSX
    :synopsis: A wraper to call VARANT

.. moduleauthor:: Kunal Kundu (kunal.kundu@tcs.com)

This modules is a wrapper to call VARANT. The inputs are -
1. Unannotated VCF file path
2. Path to create annotated vcf file (Option)
"""
import os
from gcn.lib.varann.vartype.varant import annotator
import argparse
import time
import datetime
from gcn.etc.fileconfig import getlogger, FILECONFIG


class AnnotPline:

    def __init__(self, invcf, outvcf=None):
        self.invcf = invcf
        ts = datetime.datetime.fromtimestamp(
                            time.time()).strftime('%Y%m%d_%H%M')
        if outvcf:
            self.outvcf = outvcf
            FILECONFIG['LOGFILE'] = os.path.splitext(self.outvcf)[0] + \
                                    '.varant.%s.log' % ts
        else:
            self.outvcf = os.path.splitext(invcf)[0] + '.varant.%s.vcf' % ts
            FILECONFIG['LOGFILE'] = os.path.splitext(invcf)[0] +\
                                    '.varant.%s.log' % ts
        self.logger = getlogger()
        status = self._check_env()  # Check Environment variable setting
        if status == 1:
            d = 'There seems to be problem with setting the '\
                'environment variables..'
            self.logger.error(d)
            print d
        else:
            self.logger.info('Environment variable check successful..')

    def _check_env(self):
        flag = 0
        envs = ['GCN', 'GCN_DATA_DIR', 'GCN_DB_DIR']
        for env in envs:
            if env in os.environ:
                loc = os.environ[env]
                if not os.path.exists(loc):
                    self.logger.error('Path set to %s environment does not '
                                      'exist..' % env)
                    flag = 1
            else:
                self.logger.error('%s environment variable is not set..' % env)
                flag = 1
        return flag

    def annotate_varant(self):
        'Annotate the VCF using VARANT'
        self.logger.info('Input file = %s, Output file = %s' %
                         (self.invcf, self.outvcf))
        try:
            annotator.main(self.invcf, self.outvcf, self.logger)
            d = 'Annotation complete..'
            self.logger.info(d)
            print d
        except:
            d = 'Annotation failed..'
            self.logger.error(d)
            print d


def main():
    """Main script to annotate VCF file"""

    outvcf = None
    desc = 'VCF Annotator'
    parser = argparse.ArgumentParser(description=desc)
    parser.add_argument('-i', '--inputVCF', dest='invcf', type=str,
                        help='Input VCF file path')
    parser.add_argument('-o', '--outVCF', dest='outvcf', type=str,
                        default=outvcf, help='Output VCF file path')
    args = parser.parse_args()
    ap = AnnotPline(args.invcf, args.outvcf)
    ap.annotate_varant()


if __name__ == "__main__":
    main()
